@@ -22,7 +22,7 @@ from sqlalchemy.connectors.pyodbc import PyODBCConnector
 from .base import _SelectLastRowIDMixin, DB2ExecutionContext, DB2Dialect
 from . import reflection as ibm_reflection
 
-class DB2ExecutionContext_pyodbc(_SelectLastRowIDMixin, DB2ExecutionContext):
+class DB2ExecutionContext_pyodbc(DB2ExecutionContext):
     pass
 
 class DB2Dialect_pyodbc(PyODBCConnector, DB2Dialect):
@@ -48,7 +48,7 @@ class DB2Dialect_pyodbc(PyODBCConnector, DB2Dialect):
                 connect_args[param] = util.asbool(keys.pop(param))
 
         if 'odbc_connect' in keys:
-            connectors = [urllib.unquote_plus(keys.pop('odbc_connect'))]
+            connectors = [urllib.parse.unquote_plus(keys.pop('odbc_connect'))]
         else:
             dsn_connection = 'dsn' in keys or \
                                     ('host' in keys and 'database' not in keys)
@@ -112,7 +112,7 @@ class AS400Dialect_pyodbc(PyODBCConnector, DB2Dialect):
             connect_args[param] = util.asbool(keys.pop(param))
 
         if 'odbc_connect' in keys:
-          connectors = [urllib.unquote_plus(keys.pop('odbc_connect'))]
+          connectors = [urllib.parse.unquote_plus(keys.pop('odbc_connect'))]
         else:
           dsn_connection = 'dsn' in keys or \
                                     ('host' in keys and 'database' not in keys)
